@@ -1,10 +1,10 @@
 //
 // VMime library (http://www.vmime.org)
-// Copyright (C) 2002-2006 Vincent Richard <vincent@vincent-richard.net>
+// Copyright (C) 2002-2009 Vincent Richard <vincent@vincent-richard.net>
 //
 // This program is free software; you can redistribute it and/or
 // modify it under the terms of the GNU General Public License as
-// published by the Free Software Foundation; either version 2 of
+// published by the Free Software Foundation; either version 3 of
 // the License, or (at your option) any later version.
 //
 // This program is distributed in the hope that it will be useful,
@@ -55,13 +55,13 @@ public:
 	  *
 	  * @return true if this address is empty
 	  */
-	virtual const bool isEmpty() const = 0;
+	virtual bool isEmpty() const = 0;
 
 	/** Test whether this is object is a mailboxGroup.
 	  *
 	  * @return true if this is a mailboxGroup, false otherwise
 	  */
-	virtual const bool isGroup() const = 0;
+	virtual bool isGroup() const = 0;
 
 	virtual ref <component> clone() const = 0;
 
