@@ -1,10 +1,10 @@
 //
 // VMime library (http://www.vmime.org)
-// Copyright (C) 2002-2006 Vincent Richard <vincent@vincent-richard.net>
+// Copyright (C) 2002-2009 Vincent Richard <vincent@vincent-richard.net>
 //
 // This program is free software; you can redistribute it and/or
 // modify it under the terms of the GNU General Public License as
-// published by the Free Software Foundation; either version 2 of
+// published by the Free Software Foundation; either version 3 of
 // the License, or (at your option) any later version.
 //
 // This program is distributed in the hope that it will be useful,
@@ -32,8 +32,8 @@ namespace vmime
 {
 
 
-/** This abstract class is the base for all the classes in the library.
-  * It defines the methods for parsing and generating all the components.
+/** This abstract class is the base class for all the components of a message.
+  * It defines methods for parsing and generating a component.
   */
 
 class component : public object
@@ -98,7 +98,7 @@ public:
 	  * @return start position in parsed buffer
 	  * or 0 if this component has not been parsed
 	  */
-	const string::size_type getParsedOffset() const;
+	string::size_type getParsedOffset() const;
 
 	/** Return the length of this component in the
 	  * parsed message contents.
@@ -106,7 +106,7 @@ public:
 	  * @return length of the component in parsed buffer
 	  * or 0 if this component has not been parsed
 	  */
-	const string::size_type getParsedLength() const;
+	string::size_type getParsedLength() const;
 
 	/** Return the list of children of this component.
 	  *
