@@ -1,10 +1,10 @@
 //
 // VMime library (http://www.vmime.org)
-// Copyright (C) 2002-2006 Vincent Richard <vincent@vincent-richard.net>
+// Copyright (C) 2002-2009 Vincent Richard <vincent@vincent-richard.net>
 //
 // This program is free software; you can redistribute it and/or
 // modify it under the terms of the GNU General Public License as
-// published by the Free Software Foundation; either version 2 of
+// published by the Free Software Foundation; either version 3 of
 // the License, or (at your option) any later version.
 //
 // This program is distributed in the hope that it will be useful,
@@ -41,8 +41,13 @@ class fileAttachment : public defaultAttachment
 {
 public:
 
-	fileAttachment(const string& filename, const mediaType& type, const text& desc = NULL_TEXT);
-	fileAttachment(const string& filename, const mediaType& type, const encoding& enc, const text& desc = NULL_TEXT);
+	fileAttachment(const string& filepath, const mediaType& type);
+	fileAttachment(const string& filepath, const mediaType& type, const text& desc);
+	fileAttachment(const string& filepath, const mediaType& type, const text& desc, const encoding& enc);
+
+	fileAttachment(ref <utility::inputStream> is, const word& filename, const mediaType& type);
+	fileAttachment(ref <utility::inputStream> is, const word& filename, const mediaType& type, const text& desc);
+	fileAttachment(ref <utility::inputStream> is, const word& filename, const mediaType& type, const text& desc, const encoding& enc);
 
 	/** Stores information about a file attachment.
 	  */
@@ -58,13 +63,13 @@ public:
 		  * @return true if the 'filename' property is set,
 		  * false otherwise
 		  */
-		const bool hasFilename() const;
+		bool hasFilename() const;
 
 		/** Return the value of the 'filename' property.
 		  *
 		  * @return file name
 		  */
-		const string& getFilename() const;
+		const word& getFilename() const;
 
 		/** Set the value of the 'filename' property.
 		  *
@@ -72,12 +77,18 @@ public:
 		  */
 		void setFilename(const string& name);
 
+		/** Set the value of the 'filename' property.
+		  *
+		  * @param name file name
+		  */
+		void setFilename(const word& name);
+
 		/** Check whether the 'creation-date' property is present.
 		  *
 		  * @return true if the 'creation-date' property is set,
 		  * false otherwise
 		  */
-		const bool hasCreationDate() const;
+		bool hasCreationDate() const;
 
 		/** Return the value of the 'creation-date' property.
 		  *
@@ -96,7 +107,7 @@ public:
 		  * @return true if the 'modification-date' property is set,
 		  * false otherwise
 		  */
-		const bool hasModificationDate() const;
+		bool hasModificationDate() const;
 
 		/** Return the value of the 'modification-date' property.
 		  *
@@ -115,7 +126,7 @@ public:
 		  * @return true if the 'read-date' property is set,
 		  * false otherwise
 		  */
-		const bool hasReadDate() const;
+		bool hasReadDate() const;
 
 		/** Return the value of the 'read-date' property.
 		  *
@@ -134,13 +145,13 @@ public:
 		  * @return true if the 'size' property is set,
 		  * false otherwise
 		  */
-		const bool hasSize() const;
+		bool hasSize() const;
 
 		/** Return the value of the 'size' property.
 		  *
 		  * @return file size
 		  */
-		const unsigned int getSize() const;
+		unsigned int getSize() const;
 
 		/** Set the value of the 'size' property.
 		  *
@@ -150,7 +161,7 @@ public:
 
 	private:
 
-		string* m_filename;
+		word* m_filename;
 		unsigned int* m_size;
 		datetime* m_creationDate;
 		datetime* m_modifDate;
@@ -162,7 +173,8 @@ public:
 
 private:
 
-	void setData(const string& filename);
+	void setData(const string& filepath);
+	void setData(ref <utility::inputStream> is);
 
 	fileInfo m_fileInfo;
 
