@@ -1,10 +1,10 @@
 //
 // VMime library (http://www.vmime.org)
-// Copyright (C) 2002-2006 Vincent Richard <vincent@vincent-richard.net>
+// Copyright (C) 2002-2009 Vincent Richard <vincent@vincent-richard.net>
 //
 // This program is free software; you can redistribute it and/or
 // modify it under the terms of the GNU General Public License as
-// published by the Free Software Foundation; either version 2 of
+// published by the Free Software Foundation; either version 3 of
 // the License, or (at your option) any later version.
 //
 // This program is distributed in the hope that it will be useful,
@@ -63,11 +63,11 @@ private:
 
 public:
 
-	const int getMode() const;
+	int getMode() const;
 
-	const int getType();
+	int getType();
 
-	const int getFlags();
+	int getFlags();
 
 	const folder::path::component getName() const;
 	const folder::path getFullPath() const;
@@ -76,16 +76,16 @@ public:
 	void close(const bool expunge);
 	void create(const int type);
 
-	const bool exists();
+	bool exists();
 
 	void destroy();
 
-	const bool isOpen() const;
+	bool isOpen() const;
 
 	ref <message> getMessage(const int num);
 	std::vector <ref <message> > getMessages(const int from = 1, const int to = -1);
 	std::vector <ref <message> > getMessages(const std::vector <int>& nums);
-	const int getMessageCount();
+	int getMessageCount();
 
 	ref <folder> getFolder(const folder::path::component& name);
 	std::vector <ref <folder> > getFolders(const bool recursive = false);
@@ -119,7 +119,7 @@ public:
 	void fetchMessages(std::vector <ref <message> >& msg, const int options, utility::progressListener* progress = NULL);
 	void fetchMessage(ref <message> msg, const int options);
 
-	const int getFetchCapabilities() const;
+	int getFetchCapabilities() const;
 
 private:
 
