@@ -1,10 +1,10 @@
 //
 // VMime library (http://www.vmime.org)
-// Copyright (C) 2002-2006 Vincent Richard <vincent@vincent-richard.net>
+// Copyright (C) 2002-2009 Vincent Richard <vincent@vincent-richard.net>
 //
 // This program is free software; you can redistribute it and/or
 // modify it under the terms of the GNU General Public License as
-// published by the Free Software Foundation; either version 2 of
+// published by the Free Software Foundation; either version 3 of
 // the License, or (at your option) any later version.
 //
 // This program is distributed in the hope that it will be useful,
@@ -31,6 +31,8 @@
 #include "vmime/utility/progressListener.hpp"
 #include "vmime/utility/stream.hpp"
 
+#include "vmime/message.hpp"
+
 
 namespace vmime {
 namespace net {
@@ -82,14 +84,14 @@ public:
 	  *
 	  * @return size of the part (in bytes)
 	  */
-	virtual const int getSize() const = 0;
+	virtual int getSize() const = 0;
 
 	/** Return the part sequence number (index).
 	  * The first part is at index zero.
 	  *
 	  * @return part number
 	  */
-	virtual const int getNumber() const = 0;
+	virtual int getNumber() const = 0;
 
 	/** Return the sub-part at the specified position (zero is the
 	  * first part).
@@ -111,7 +113,7 @@ public:
 	  *
 	  * @return number of sub-parts
 	  */
-	const int getPartCount() const;
+	int getPartCount() const;
 };
 
 
@@ -149,7 +151,7 @@ public:
 	  *
 	  * @return number of parts
 	  */
-	virtual const int getPartCount() const = 0;
+	virtual int getPartCount() const = 0;
 };
 
 
@@ -194,7 +196,7 @@ public:
 	  *
 	  * @return sequence number of the message
 	  */
-	virtual const int getNumber() const = 0;
+	virtual int getNumber() const = 0;
 
 	/** Return the unique identified of this message (must fetch before).
 	  *
@@ -206,14 +208,14 @@ public:
 	  *
 	  * @return size of the message (in bytes)
 	  */
-	virtual const int getSize() const = 0;
+	virtual int getSize() const = 0;
 
 	/** Check whether this message has been expunged
 	  * (ie: definitively deleted).
 	  *
 	  * @return true if the message is expunged, false otherwise
 	  */
-	virtual const bool isExpunged() const = 0;
+	virtual bool isExpunged() const = 0;
 
 	/** Possible flags for a message.
 	  */
@@ -225,6 +227,7 @@ public:
 		FLAG_REPLIED = (1 << 3),   /**< User replied to this message. */
 		FLAG_MARKED  = (1 << 4),   /**< Used-defined flag. */
 		FLAG_PASSED  = (1 << 5),   /**< Message has been resent/forwarded/bounced. */
+		FLAG_DRAFT   = (1 << 6),   /**< Message is marked as a 'draft'. */
 
 		FLAG_UNDEFINED = 9999      /**< Used internally (this should not be returned
 		                                by the flags() function). */
@@ -243,7 +246,7 @@ public:
 	  *
 	  * @return flags of the message
 	  */
-	virtual const int getFlags() const = 0;
+	virtual int getFlags() const = 0;
 
 	/** Set the flags of this message.
 	  *
@@ -286,6 +289,16 @@ public:
 	  * @param p the part for which to fetch the header
 	  */
 	virtual void fetchPartHeader(ref <part> p) = 0;
+
+	/** Get the RFC-822 message for this abstract message.
+	  * Warning: This may require getting some data (ie: structure and headers) from
+	  * the server, which is done automatically. Actual message contents (ie: body)
+	  * will not be fetched if possible (IMAP allows it, whereas POP3 will require
+	  * to fetch the whole message).
+	  *
+	  * @return a RFC-822-parsed message
+	  */
+	virtual ref <vmime::message> getParsedMessage() = 0;
 };
 
 
