@@ -1,10 +1,10 @@
 //
 // VMime library (http://www.vmime.org)
-// Copyright (C) 2002-2006 Vincent Richard <vincent@vincent-richard.net>
+// Copyright (C) 2002-2009 Vincent Richard <vincent@vincent-richard.net>
 //
 // This program is free software; you can redistribute it and/or
 // modify it under the terms of the GNU General Public License as
-// published by the Free Software Foundation; either version 2 of
+// published by the Free Software Foundation; either version 3 of
 // the License, or (at your option) any later version.
 //
 // This program is distributed in the hope that it will be useful,
@@ -72,7 +72,7 @@ public:
 	  *
 	  * @return true if the specified folder name is valid, false otherwise
 	  */
-	virtual const bool isValidFolderName(const folder::path::component& name) const = 0;
+	virtual bool isValidFolderName(const folder::path::component& name) const = 0;
 
 	/** Store capabilities. */
 	enum Capabilities
@@ -92,10 +92,10 @@ public:
 	  *
 	  * @return features supported by this service
 	  */
-	virtual const int getCapabilities() const = 0;
+	virtual int getCapabilities() const = 0;
 
 
-	const Type getType() const { return (TYPE_STORE); }
+	Type getType() const { return (TYPE_STORE); }
 };
 
 
