@@ -1,10 +1,10 @@
 //
 // VMime library (http://www.vmime.org)
-// Copyright (C) 2002-2006 Vincent Richard <vincent@vincent-richard.net>
+// Copyright (C) 2002-2009 Vincent Richard <vincent@vincent-richard.net>
 //
 // This program is free software; you can redistribute it and/or
 // modify it under the terms of the GNU General Public License as
-// published by the Free Software Foundation; either version 2 of
+// published by the Free Software Foundation; either version 3 of
 // the License, or (at your option) any later version.
 //
 // This program is distributed in the hope that it will be useful,
@@ -25,6 +25,8 @@
 #define VMIME_UTILITY_FILTEREDSTREAM_HPP_INCLUDED
 
 
+#include <algorithm>
+
 #include "vmime/utility/stream.hpp"
 
 
@@ -39,6 +41,8 @@ class filteredInputStream : public inputStream
 {
 public:
 
+	virtual size_type getBlockSize();
+
 	/** Return a reference to the stream being filtered.
 	  *
 	  * @return stream being filtered
@@ -54,6 +58,8 @@ class filteredOutputStream : public outputStream
 {
 public:
 
+	virtual size_type getBlockSize();
+
 	/** Return a reference to the stream being filtered.
 	  *
 	  * @return destination stream for filtered data
@@ -78,13 +84,13 @@ public:
 
 	inputStream& getPreviousInputStream();
 
-	const bool eof() const;
+	bool eof() const;
 
 	void reset();
 
-	const size_type read(value_type* const data, const size_type count);
+	size_type read(value_type* const data, const size_type count);
 
-	const size_type skip(const size_type count);
+	size_type skip(const size_type count);
 
 private:
 
@@ -171,7 +177,7 @@ public:
 		return (m_stream);
 	}
 
-	const bool eof() const
+	bool eof() const
 	{
 		return (m_found == COUNT || m_eof);
 	}
@@ -182,9 +188,9 @@ public:
 		m_stream.reset();
 	}
 
-	const size_type read(value_type* const data, const size_type count);
+	size_type read(value_type* const data, const size_type count);
 
-	const size_type skip(const size_type /* count */)
+	size_type skip(const size_type /* count */)
 	{
 		// Not supported
 		return 0;
@@ -202,12 +208,12 @@ private:
 
 
 template <>
-const stream::size_type stopSequenceFilteredInputStream <1>::read
+stream::size_type stopSequenceFilteredInputStream <1>::read
 	(value_type* const data, const size_type count);
 
 
 template <int COUNT>
-const stream::size_type stopSequenceFilteredInputStream <COUNT>::read
+stream::size_type stopSequenceFilteredInputStream <COUNT>::read
 	(value_type* const data, const size_type count)
 {
 	// Read buffer must be at least 'COUNT' size + 1 byte
