@@ -1,10 +1,10 @@
 //
 // VMime library (http://www.vmime.org)
-// Copyright (C) 2002-2006 Vincent Richard <vincent@vincent-richard.net>
+// Copyright (C) 2002-2009 Vincent Richard <vincent@vincent-richard.net>
 //
 // This program is free software; you can redistribute it and/or
 // modify it under the terms of the GNU General Public License as
-// published by the Free Software Foundation; either version 2 of
+// published by the Free Software Foundation; either version 3 of
 // the License, or (at your option) any later version.
 //
 // This program is distributed in the hope that it will be useful,
@@ -48,7 +48,7 @@ public:
 	  *
 	  * @return true to cancel the operation, false otherwise
 	  */
-	virtual const bool cancel() const = 0;
+	virtual bool cancel() const = 0;
 
 	/** Called at the beginning of the operation.
 	  *
@@ -88,7 +88,7 @@ public:
 	  */
 	progressListenerSizeAdapter(progressListener* list, const int total);
 
-	const bool cancel() const;
+	bool cancel() const;
 
 	void start(const int predictedTotal);
 	void progress(const int current, const int currentTotal);
